==> aws-cdk.aws-secretsmanager-1.28.0.tar.gz: aws-cdk.aws-secretsmanager-1.28.0/setup.py <==
import json
import setuptools

kwargs = json.loads("""
{
    "name": "aws-cdk.aws-secretsmanager",
    "version": "1.28.0",
    "description": "The CDK Construct Library for AWS::SecretsManager",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_secretsmanager",
        "aws_cdk.aws_secretsmanager._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_secretsmanager._jsii": [
            "aws-secretsmanager@1.28.0.jsii.tgz"
        ],
        "aws_cdk.aws_secretsmanager": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "jsii~=0.22.0",
        "publication>=0.0.3",
        "aws-cdk.aws-ec2==1.28.0",
        "aws-cdk.aws-iam==1.28.0",
        "aws-cdk.aws-kms==1.28.0",
        "aws-cdk.aws-lambda==1.28.0",
        "aws-cdk.aws-sam==1.28.0",
        "aws-cdk.core==1.28.0"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ]
}
""")

with open('README.md') as fp:
    kwargs['long_description'] = fp.read()


setuptools.setup(**kwargs)

==> aws-cdk.aws-secretsmanager-1.29.0.tar.gz: aws-cdk.aws-secretsmanager-1.29.0/setup.py <==
import json
import setuptools

kwargs = json.loads("""
{
    "name": "aws-cdk.aws-secretsmanager",
    "version": "1.29.0",
    "description": "The CDK Construct Library for AWS::SecretsManager",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_secretsmanager",
        "aws_cdk.aws_secretsmanager._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_secretsmanager._jsii": [
            "aws-secretsmanager@1.29.0.jsii.tgz"
        ],
        "aws_cdk.aws_secretsmanager": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "jsii~=0.22.0",
        "publication>=0.0.3",
        "aws-cdk.aws-ec2==1.29.0",
        "aws-cdk.aws-iam==1.29.0",
        "aws-cdk.aws-kms==1.29.0",
        "aws-cdk.aws-lambda==1.29.0",
        "aws-cdk.aws-sam==1.29.0",
        "aws-cdk.core==1.29.0",
        "constructs>=1.1.2, <2.0.0"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ]
}
""")

with open('README.md') as fp:
    kwargs['long_description'] = fp.read()


setuptools.setup(**kwargs)
